@@ -2,12 +2,14 @@ use std::fs;
 use std::path::PathBuf;
 use std::process::{Command, Stdio};
 
-use anyhow::{anyhow, bail, Error};
+use anyhow::{anyhow, bail, Context, Error};
 use clap::Parser;
 use console::style;
 
-use crate::bootstrap::ensure_self_venv;
+use crate::bootstrap::{fetch, FetchOptions};
 use crate::config::Config;
+
+use crate::platform::get_toolchain_python_bin;
 use crate::pyproject::{locate_projects, PyProject};
 use crate::utils::{get_venv_python_bin, prepend_path_to_path_env, CommandOutput, IoPathContext};
 use crate::uv::UvBuilder;
@@ -46,8 +48,8 @@ pub struct Args {
 
 pub fn execute(cmd: Args) -> Result<(), Error> {
     let output = CommandOutput::from_quiet_and_verbose(cmd.quiet, cmd.verbose);
-    let self_venv = ensure_self_venv(output)?;
     let project = PyProject::load_or_discover(cmd.pyproject.as_deref())?;
+    let py_ver = project.venv_python_version()?;
 
     let out = match cmd.out {
         Some(path) => path,
@@ -66,6 +68,32 @@ pub fn execute(cmd: Args) -> Result<(), Error> {
     let use_uv = Config::current().use_uv();
     let projects = locate_projects(project, cmd.all, &cmd.package[..])?;
 
+    let all_virtual = projects.iter().all(|p| p.is_virtual());
+    if all_virtual {
+        warn!("skipping build, all projects are virtual");
+        return Ok(());
+    }
+
+    // Make sure we have a compatible Python version.
+    let py_ver = fetch(&py_ver.into(), FetchOptions::with_output(output))
+        .context("failed fetching toolchain ahead of sync")?;
+    echo!(if output, "Python version: {}", style(&py_ver).cyan());
+    let py_bin = get_toolchain_python_bin(&py_ver)?;
+
+    // Create a virtual environment in which to perform the builds.
+    let uv = UvBuilder::new()
+        .with_output(CommandOutput::Quiet)
+        .ensure_exists()?;
+    let venv_dir = tempfile::tempdir().context("failed to create temporary directory")?;
+    let uv_venv = uv
+        .venv(venv_dir.path(), &py_bin, &py_ver, None)
+        .context("failed to create build environment")?;
+    uv_venv.write_marker()?;
+    uv_venv.bootstrap()?;
+
+    // Respect the output level for the actual builds.
+    let uv = uv.with_output(output);
+
     for project in projects {
         // skip over virtual packages on build
         if project.is_virtual() {
@@ -78,7 +106,7 @@ pub fn execute(cmd: Args) -> Result<(), Error> {
             style(project.normalized_name()?).cyan()
         );
 
-        let mut build_cmd = Command::new(get_venv_python_bin(&self_venv));
+        let mut build_cmd = Command::new(get_venv_python_bin(venv_dir.path()));
         build_cmd
             .arg("-mbuild")
             .env("NO_COLOR", "1")
@@ -87,8 +115,6 @@ pub fn execute(cmd: Args) -> Result<(), Error> {
             .arg(&*project.root_path());
 
         if use_uv {
-            // we need to ensure uv is available to use without installing it into self_venv
-            let uv = UvBuilder::new().with_output(output).ensure_exists()?;
             let uv_dir = uv
                 .uv_bin()
                 .parent()
@@ -118,6 +144,5 @@ pub fn execute(cmd: Args) -> Result<(), Error> {
             bail!("failed to build dist");
         }
     }
-
     Ok(())
 }
