@@ -27,7 +27,7 @@ fn test_add_flask() {
 
     ----- stderr -----
     Resolved 9 packages in [EXECUTION_TIME]
-    Downloaded 9 packages in [EXECUTION_TIME]
+    Prepared 9 packages in [EXECUTION_TIME]
     Installed 9 packages in [EXECUTION_TIME]
      + blinker==1.7.0
      + click==8.1.7
@@ -62,7 +62,7 @@ fn test_add_flask_dotenv() {
 
     ----- stderr -----
     Resolved 10 packages in [EXECUTION_TIME]
-    Downloaded 10 packages in [EXECUTION_TIME]
+    Prepared 10 packages in [EXECUTION_TIME]
     Installed 10 packages in [EXECUTION_TIME]
      + blinker==1.7.0
      + click==8.1.7
@@ -114,7 +114,7 @@ fn test_add_from_find_links() {
 
     ----- stderr -----
     Resolved 3 packages in [EXECUTION_TIME]
-    Downloaded 3 packages in [EXECUTION_TIME]
+    Prepared 3 packages in [EXECUTION_TIME]
     Installed 3 packages in [EXECUTION_TIME]
      + colorama==0.4.6
      + my-project==0.1.0 (from file:[TEMP_PATH]/project)
@@ -145,7 +145,7 @@ fn test_add_flask_wrong_venv_exported() {
 
     ----- stderr -----
     Resolved 9 packages in [EXECUTION_TIME]
-    Downloaded 9 packages in [EXECUTION_TIME]
+    Prepared 9 packages in [EXECUTION_TIME]
     Installed 9 packages in [EXECUTION_TIME]
      + blinker==1.7.0
      + click==8.1.7
@@ -179,7 +179,7 @@ fn test_add_explicit_version_or_url() {
 
     ----- stderr -----
     Resolved 3 packages in [EXECUTION_TIME]
-    Downloaded 3 packages in [EXECUTION_TIME]
+    Prepared 3 packages in [EXECUTION_TIME]
     Installed 3 packages in [EXECUTION_TIME]
      + markupsafe==2.1.3
      + my-project==0.1.0 (from file:[TEMP_PATH]/project)
@@ -200,7 +200,7 @@ fn test_add_explicit_version_or_url() {
 
     ----- stderr -----
     Resolved 4 packages in [EXECUTION_TIME]
-    Downloaded 2 packages in [EXECUTION_TIME]
+    Prepared 2 packages in [EXECUTION_TIME]
     Uninstalled 1 package in [EXECUTION_TIME]
     Installed 2 packages in [EXECUTION_TIME]
      - my-project==0.1.0 (from file:[TEMP_PATH]/project)
